@@ -680,3 +680,45 @@ class TestDidlLite:
 
         item = items[0]
         assert isinstance(item, didl_lite.MusicTrack)
+
+    def test_from_xml_string_unbound_prefix(self) -> None:
+        """Test from_xml_string with unbound namespace prefix."""
+        # The key fix is adding: xmlns="urn:schemas-upnp-org:metadata-1-0/DIDL-Lite/"
+        broken_xml = (
+            '<DIDL-Lite xmlns="urn:schemas-upnp-org:metadata-1-0/DIDL-Lite/" '
+            'xmlns:dc="http://purl.org/dc/elements/1.1/" '
+            'xmlns:upnp="urn:schemas-upnp-org:metadata-1-0/upnp/" '
+            'xmlns:dlna="urn:schemas-dlna-org:metadata-1-0/">'
+            '<item id="1" parentID="0" restricted="1">'
+            "<dc:title>Test Title</dc:title>"
+            "<song:subTitle>Test Subtitle</song:subTitle>"
+            "<upnp:class>object.item.audioItem.musicTrack</upnp:class>"
+            "</item>"
+            "</DIDL-Lite>"
+        )
+
+        # This call should not throw ParseError when strict=False.
+        objs = didl_lite.from_xml_string(broken_xml, strict=False)
+
+        assert len(objs) == 1
+        assert objs[0].title == "Test Title"
+        # Check that the temporary namespace is correctly assigned.
+        assert "sub_title" in objs[0].__dict__
+        assert objs[0].sub_title == "Test Subtitle"
+        assert isinstance(objs[0], didl_lite.MusicTrack)
+
+    def test_music_track_artist_and_genre(self) -> None:
+        """Test MusicTrack artist and genre properties."""
+        track = didl_lite.MusicTrack(
+            id="1",
+            parent_id="0",
+            title="Test",
+            restricted="0",
+            artist="My Artist",
+            genre="My Genre",
+        )
+
+        xml = didl_lite.to_xml_string(track)
+
+        assert b"<upnp:artist>My Artist</upnp:artist>" in xml
+        assert b"<upnp:genre>My Genre</upnp:genre>" in xml
